#!/bin/bash


HELP=0; NEMO_BRAN='trunk'; NPROC=1
SVN_URL='https://forge.ipsl.jussieu.fr/nemo/svn'

while [ $# -ne 0 ]; do
    case $1 in
	'-b'|'--branch') NEMO_BRAN=$2; shift 2;; '-d'|'--directory') INSTALL_DIR=$2; shift 2;;
	'-j'|'--job'   ) NPROC=$2    ; shift 2;; '-m'|'--machine'  ) NEMO_HPCC=$2  ; shift 2;;
	'-h'|'--help'  ) HELP=1      ; shift  ;; '-u'|'--username' ) SVN_USER=$2   ; shift 2;;
	"*"            ) HELP=1      ; shift  ;;
    esac
done

if [[ -z "${INSTALL_DIR}" || -z "${NEMO_HPCC}" || $HELP == 1 ]]; then
    echo 'Error'
    exit 1
fi

if   [ ${NEMO_BRAN} == 'trunk' ]; then
    svn_bran=${NEMO_BRAN}
elif [ $( svn ls ${SVN_URL}/branches/2015 | grep -oe "\<${NEMO_BRAN}\>") ]; then
    svn_bran=branches/2015/${NEMO_BRAN}
else
    printf "\nNEMO branch name \033[0;31m%s\033[0m given is not recognized\n\n" ${NEMO_BRAN}
    echo 'List of existing branches on repository in branches/2015:'
    svn ls ${SVN_URL}/branches/2015 | tr -d / | xargs -n 3 printf "%-35s\t%-35s\t%-35s\n"
    echo
    exit 1
fi

printf "\nInstallation of NEMO trusting monitoring in %s on %s branch for %s\n\n" \
    ${INSTALL_DIR} ${NEMO_BRAN} ${NEMO_HPCC}

echo 'Initial checkout of '${NEMO_BRAN}' branch'
mkdir -p ${INSTALL_DIR}/${NEMO_BRAN}/NEMOGCM && cd ${INSTALL_DIR}/${NEMO_BRAN}/NEMOGCM

for elmt in 'ARCH' 'CONFIG' 'NEMO' 'EXTERNAL' 'TOOLS' 'TRUST'; do
    rev=''
    printf "%s " $elmt
    [ $elmt == 'TRUST' ] && svn_bran='branches/2015/dev_r5092_CNRS18_TRUST' && rev='-r 5697'
    svn co -q $rev ${SVN_URL}/${svn_bran}/NEMOGCM/$elmt
done

printf "\n\nCleaning EXTERNAL directory\n"
cd EXTERNAL
printf 'Remove '

for elmt in $( find -maxdepth 1 -type d -name '[^.]*' ); do
    if [ ! $( echo $elmt | grep "AGRIF\|IOIPSL\|fcm" ) ]; then
	printf "%s " $elmt && rm -rf $elmt > /dev/null
    fi
done
printf "\n"


printf "\nCleaning TOOLS directory\n"
cd ../TOOLS
printf 'Remove '

for elmt in $( find -maxdepth 1 -type d -name '[^.]*' ); do
    if [ ! $( echo $elmt | grep "COMPILE\|maketools\|REBUILD_NEMO" ) ]; then
	printf "%s " $elmt && rm -rf $elmt > /dev/null
    fi
done
printf "\n\n"

if [ $( find ../ARCH -name arch-${NEMO_HPCC}.fcm ) ]; then
    echo 'Compile NEMO rebuild tool'
    ./maketools -n REBUILD_NEMO -m ${NEMO_HPCC} -j $NPROC >& /dev/null
    [ $? -eq 0 ] && printf "\033[0;32mOK\033[0m" || printf "\033[0;31mKO\033[0m"
    printf "\n\n"
else
    printf "\033[0;31mNo arch file found to compile NEMO rebuild tool\033[0m\n\n"
fi
